# Work around for R CMD CHECK
utils::globalVariables(names = c(
  ".",
  "term_label",
  "level",
  "level_no",
  "reference",
  "variable",
  "estimate",
  "y",
  "conf.low",
  "conf.high",
  "width",
  "display",
  "rel_x",
  "rel_width",
  "abs_x",
  "abs_width",
  "hjust",
  "abs_end_x",
  "heading",
  "text_x",
  "xmin",
  "xmax",
  "ymin",
  "ymax",
  "x",
  "linetype",
  "group",
  "label",
  "fontface",
  ".section",
  ".band",
  ".diamond",
  ".whole_row",
  "vi",
  "yi",
  "ni",
  "se",
  "item",
  "subheading",
  "whole_row",
  "band",
  "section",
  "diamond",
  "size",
  "trans_char",
  ".event_time",
  ".event_status",
  "term"
))
